@@ -26,13 +26,6 @@ def launch_driver(url=''):
         driver.get(url)
     return driver
 
-def wait_until(func, arg, interval=1):
-    while True:
-        try:
-            return func(arg)
-        except:
-            time.sleep(interval)
-
 def ray_crosses_edge(point, v1, v2):
     '''
     Test whether a point lies within a polygon, excluding vertices and edges
@@ -44,13 +37,6 @@ def ray_crosses_edge(point, v1, v2):
         return False
     return not (point.y <= v2.y - (v2.x - point.x) * get_slope(v1, v2))
 
-def max_length_list(alist):
-    max_list = None
-    for sublist in alist:
-        if max_list is None or len(sublist) > len(max_list):
-            max_list = sublist
-    return max_list
-
 def get_water_multiplier(node1, node2, rgb_image):
     '''
     Return approximate water multiplication factor between two nodes
@@ -136,7 +122,7 @@ def add_polygons_to_placemark(placemark, polygons):
         add_coordinates_to_boundary(boundary, poly.nodes)
         if poly.inner is not None:
             boundary = ET.SubElement(polygon, 'innerBoundaryIs')
-            add_coordinates_to_boundary(boundary, poly.nodes)
+            add_coordinates_to_boundary(boundary, poly.inner.nodes)
 
 def add_placemark(root, location):
     placemark = ET.SubElement(root, 'Placemark')
